/**
 *  Licensed under GPL. For more information, see
 *    http://jaxodraw.sourceforge.net/license.html
 *  or the LICENSE file in the jaxodraw distribution.
 */
package net.sf.jaxodraw.gui.panel.edit;

import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.GridLayout;
import java.awt.Insets;
import java.awt.Point;

import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import javax.swing.border.TitledBorder;

import net.sf.jaxodraw.gui.swing.spinner.JaxoFixedJSpinner;


/** A panel to change the x,y and radius parameters of an object.
 * @since 2.0
 */
public class Jaxo2PointsEditPanel extends JaxoEditPanel {
    private static final long serialVersionUID = 7526471155622776147L;
    private transient JSpinner spxin;
    private transient JSpinner spyin;
    private transient JSpinner spxfin;
    private transient JSpinner spyfin;

    /** Constructor: returns a 2Points edit panel with
     * default value 0 for all variables.
     */
    public Jaxo2PointsEditPanel() {
        Point p = new Point();
        init(new Point[] {p, p});
    }

    /**
     * Constructor: returns a 2Points edit panel.
     *
     * @param points The initial points of the sub-panel.
     */
    public Jaxo2PointsEditPanel(Point[] points) {
        init(points);
    }

    private void init(Point[] p) {
        Dimension size = new Dimension(120, 20);
        GridLayout layout = new GridLayout(0, 2);

        JPanel pxin = new JPanel();
        pxin.setLayout(layout);

        SpinnerNumberModel modelXin = new SpinnerNumberModel();
        modelXin.setValue(new Integer(p[0].x));
        JLabel jxin = createLabel("Xin: ");
        pxin.add(jxin);

        this.spxin = new JaxoFixedJSpinner(modelXin);
        spxin.setName("spx");
        pxin.add(spxin);

        JPanel pyin = new JPanel();
        pyin.setLayout(layout);

        SpinnerNumberModel modelYin = new SpinnerNumberModel();
        modelYin.setValue(new Integer(p[0].y));
        JLabel jyin = createLabel("Yin: ");
        pyin.add(jyin);

        this.spyin = new JaxoFixedJSpinner(modelYin);
        spyin.setName("spy");
        pyin.add(spyin);

        JPanel pxfin = new JPanel();
        pxfin.setLayout(layout);

        SpinnerNumberModel modelXfin = new SpinnerNumberModel();
        modelXfin.setValue(new Integer(p[1].x));
        JLabel jxfin = createLabel("Xfin: ");
        pxfin.add(jxfin);

        this.spxfin = new JaxoFixedJSpinner(modelXfin);
        spxfin.setName("spxfin");
        pxfin.add(spxfin);

        JPanel pyfin = new JPanel();
        pyfin.setLayout(layout);

        SpinnerNumberModel modelYfin = new SpinnerNumberModel();
        modelYfin.setValue(new Integer(p[1].y));
        JLabel jyfin = createLabel("Yfin: ");
        pyfin.add(jyfin);

        this.spyfin = new JaxoFixedJSpinner(modelYfin);
        spyfin.setName("spyfin");
        pyfin.add(spyfin);

        JPanel dimSPanel = new JPanel();
        GridBagLayout gb = new GridBagLayout();
        GridBagConstraints sc = new GridBagConstraints();
        dimSPanel.setLayout(gb);

        sc.gridx = 0;
        sc.gridy = 0;
        pxin.setPreferredSize(size);
        dimSPanel.add(pxin, sc);

        sc.gridx = 0;
        sc.gridy = 1;
        sc.insets = new Insets(5, 0, 5, 0);
        pyin.setPreferredSize(size);
        dimSPanel.add(pyin, sc);

        sc.gridx = 1;
        sc.gridy = 0;
        sc.insets = new Insets(0, 0, 0, 5);
        pxfin.setPreferredSize(size);
        dimSPanel.add(pxfin, sc);

        sc.gridx = 1;
        sc.gridy = 1;
        sc.insets = new Insets(5, 0, 5, 5);
        pyfin.setPreferredSize(size);
        dimSPanel.add(pyfin, sc);

        setLineBoxLayout();

        TitledBorder dimSTitle =
            createI18NBorder("Jaxo2PointsEditPanel.title");
        this.setBorder(dimSTitle);
        this.add(dimSPanel);
    }

    /** {@inheritDoc} */
    public void addEditPanelListener(JaxoEditPanelListener listener) {
        if (listener != null) {
            spxin.addChangeListener(listener);
            spxfin.addChangeListener(listener);
            spyin.addChangeListener(listener);
            spyfin.addChangeListener(listener);
        }
    }
}
