/**
 *  Licensed under GPL. For more information, see
 *    http://jaxodraw.sourceforge.net/license.html
 *  or the LICENSE file in the jaxodraw distribution.
 */
package net.sf.jaxodraw.gui.panel.edit;

import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.border.TitledBorder;

import net.sf.jaxodraw.util.JaxoLanguage;


/** A panel to change the arrow of an object.
 * @since 2.0
 */
public class JaxoArrowEditPanel extends JaxoEditPanel {
    private static final long serialVersionUID = 7526471155622776147L;
    private transient JCheckBox arrowcb;
    private transient JCheckBox flipcb;
    private transient JPanel arrEPanel;
    private transient GridBagLayout gb;
    private transient GridBagConstraints sc;
    private transient JSpinner spstin;

    /** Constructor: an arrow edit panel with arrow not flipped. */
    public JaxoArrowEditPanel() {
        init(true, false, 0.5f);
    }

     /** Constructor: returns a arrow edit panel with the given params.
     * @param arrow Whether the object has an arrow.
     * @param flip  Whether the arrow is flipped.
     * @param oldPosition The old position of the arrow
     */
    public JaxoArrowEditPanel(boolean arrow, boolean flip, float oldPosition) {
        init(arrow, flip, oldPosition);
    }

    private void init(boolean arrow, boolean flip, float oldPosition) {
        final JLabel arpLabel = createI18NLabel("JaxoArrowPositionEditPanel.position");

        arrowcb =
            new JCheckBox(JaxoLanguage.translate("JaxoArrowEditPanel.arrow"));
        arrowcb.setName("arrow");
        arrowcb.setSelected(arrow);
        arrowcb.addItemListener(new ItemListener() {
                public final void itemStateChanged(ItemEvent e) {
                    flipcb.setEnabled(arrowcb.isSelected());
                    spstin.setEnabled(arrowcb.isSelected());
                    arpLabel.setEnabled(arrowcb.isSelected());
                }
            });

        spstin = getSpinner(oldPosition, 0.f, 1.0f, 0.005f, "arrowpos");
        JPanel arpPanel = new JPanel();
        //hard code the preferred spinner dimension (look necessary here)
        spstin.setPreferredSize(new Dimension(55, 20));
        arpPanel.add(arpLabel);
        arpPanel.add(spstin);

        flipcb =
            new JCheckBox(JaxoLanguage.translate("JaxoArrowEditPanel.flip"));
        flipcb.setName("flip");
        flipcb.setSelected(flip);
        flipcb.setEnabled(arrow);


        arrEPanel = new JPanel();
        gb = new GridBagLayout();
        sc = new GridBagConstraints();
        arrEPanel.setLayout(gb);

        sc.anchor = GridBagConstraints.WEST;

        sc.gridx = 0;
        sc.gridy = 0;
        arrEPanel.add(arrowcb, sc);

        sc.gridx = 1;
        sc.gridy = 0;
        arrEPanel.add(flipcb, sc);

        sc.gridx = 0;
        sc.gridy = 1;
        sc.gridwidth = 2;
        arrEPanel.add(arpPanel, sc);

        setLineBoxLayout();

        TitledBorder arrETitle = createI18NBorder("JaxoArrowEditPanel.title");
        this.setBorder(arrETitle);
        this.add(arrEPanel);

    }

    /** {@inheritDoc} */
    public void addEditPanelListener(JaxoEditPanelListener listener) {
        if (listener != null) {
            arrowcb.addItemListener(listener);
            flipcb.addItemListener(listener);
            spstin.addChangeListener(listener);
            //moreopt.addActionListener(listener);
        }
    }
}
