/**
 *  Licensed under GPL. For more information, see
 *    http://jaxodraw.sourceforge.net/license.html
 *  or the LICENSE file in the jaxodraw distribution.
 */
package net.sf.jaxodraw.gui.panel.edit;

import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import javax.swing.border.TitledBorder;

import net.sf.jaxodraw.gui.swing.spinner.JaxoFixedJSpinner;
import net.sf.jaxodraw.util.JaxoLanguage;


/** A panel to change the double line property of an object.
 * @since 2.0
 */
public class JaxoDLEditPanel extends JaxoEditPanel {
    private static final long serialVersionUID = 7526471155622776147L;
    private transient JCheckBox dlcb;
    private transient JSpinner spsep;

    /** Constructor: a double line edit panel with default values. */
    public JaxoDLEditPanel() {
        init(false, 1.f);
    }

    /** Constructor: a double line edit panel with the given params.
     * @param dLine Whether the object is double lined.
     * @param dLSep The double line separation.
     */
    public JaxoDLEditPanel(boolean dLine, float dLSep) {
        init(dLine, dLSep);
    }

    private void init(boolean dLine, float dLSep) {
        dlcb =
            new JCheckBox(JaxoLanguage.translate("JaxoDLEditPanel.doubleLine"));
        dlcb.setName("dLine");
        dlcb.setSelected(dLine);
        dlcb.addItemListener(new ItemListener() {
                public final void itemStateChanged(ItemEvent e) {
                    spsep.setEnabled(dlcb.isSelected());
                }
            });

        SpinnerNumberModel modelsep =
            new SpinnerNumberModel(dLSep, 0.5, 10.0, 0.5);
        JLabel stsep = createI18NLabel("JaxoDLEditPanel.separation");
        spsep = new JaxoFixedJSpinner(modelsep);
        spsep.setName("dlsep");
        spsep.setEnabled(dLine);

        JPanel dlP = new JPanel();
        GridBagLayout subdl = new GridBagLayout();
        GridBagConstraints subcdl = new GridBagConstraints();
        dlP.setLayout(subdl);

        subcdl.gridx = 0;
        subcdl.gridy = 0;
        dlP.add(dlcb, subcdl);

        subcdl.gridx = 0;
        subcdl.gridy = 1;
        subcdl.insets = new Insets(5, 0, 5, 0);
        dlP.add(stsep, subcdl);

        subcdl.gridx = 1;
        subcdl.gridy = 1;
        subcdl.insets = new Insets(5, 0, 5, 5);
        spsep.setPreferredSize(new Dimension(50, 20));
        dlP.add(spsep, subcdl);

        setLineBoxLayout();

        TitledBorder dlTitle = createI18NBorder("JaxoDLEditPanel.title");
        this.setBorder(dlTitle);
        this.add(dlP);
    }

    /** {@inheritDoc} */
    public void addEditPanelListener(JaxoEditPanelListener listener) {
        if (listener != null) {
            dlcb.addItemListener(listener);
            spsep.addChangeListener(listener);
        }
    }
}
