/**
 *  Licensed under GPL. For more information, see
 *    http://jaxodraw.sourceforge.net/license.html
 *  or the LICENSE file in the jaxodraw distribution.
 */
package net.sf.jaxodraw.gui.panel.edit;

import java.awt.GridLayout;

import javax.swing.JLabel;
import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import javax.swing.border.TitledBorder;

import net.sf.jaxodraw.gui.swing.spinner.JaxoFixedJSpinner;


/** A panel to change the wiggle of an object.
 * @since 2.0
 */
public class JaxoWiggleEditPanel extends JaxoEditPanel {
    private static final long serialVersionUID = 7526471155622776147L;

    private transient JSpinner spampin;
    private transient JSpinner spwigin;

    /** Constructor: returns a wiggle edit panel with default wiggle of 10. */
    public JaxoWiggleEditPanel() {
        init(10, 10);
    }

    /** Constructor: returns a wiggle edit panel with the given wiggle.
     * @param oldAmp The amplitude of the object to be edited by this panel.
     * @param oldWiggle The wiggle of the object to be edited by this panel.
     */
    public JaxoWiggleEditPanel(int oldAmp, int oldWiggle) {
        init(oldWiggle, oldAmp);
    }

    /** Constructor: returns a wiggle edit panel with the given wiggle.
     * @param oldAmp The amplitude of the object to be edited by this panel.
     */
    public JaxoWiggleEditPanel(int oldAmp) {
        init(oldAmp);
    }

    private void init(int oldWiggle, int oldAmp) {
        this.setLayout(new GridLayout(2, 2, 10, 0));

        JLabel ampin = createI18NLabel("JaxoWiggleEditPanel.amplitude");

        SpinnerNumberModel modelampin =
            new SpinnerNumberModel(oldAmp, -500, 500, 1);
        this.spampin = new JaxoFixedJSpinner(modelampin);
        spampin.setName("amp");

        JLabel wigin = createI18NLabel("JaxoWiggleEditPanel.wiggles");

        SpinnerNumberModel modelwigin =
            new SpinnerNumberModel(oldWiggle, 1, 1000, 1);
        this.spwigin = new JaxoFixedJSpinner(modelwigin);
        spwigin.setName("wiggle");

        TitledBorder awSTitle = createI18NBorder("JaxoWiggleEditPanel.title");
        this.setBorder(awSTitle);
        this.add(ampin);
        this.add(spampin);
        this.add(wigin);
        this.add(spwigin);
    }

    private void init(int oldAmp) {
        this.setLayout(new GridLayout(1, 0));

        JLabel ampin = createI18NLabel("JaxoWiggleEditPanel.amplitude");

        SpinnerNumberModel modelampin =
            new SpinnerNumberModel(oldAmp, -500, 500, 1);
        this.spampin = new JaxoFixedJSpinner(modelampin);
        spampin.setName("amp");

        TitledBorder awSTitle = createI18NBorder("JaxoWiggleEditPanel.title");
        this.setBorder(awSTitle);
        this.add(ampin);
        this.add(spampin);
    }

    /** {@inheritDoc} */
    public void addEditPanelListener(JaxoEditPanelListener listener) {
        if (listener != null) {
            spampin.addChangeListener(listener);
            if (spwigin != null) {
                spwigin.addChangeListener(listener);
            }
        }
    }
}
