/**
 *  Licensed under GPL. For more information, see
 *    http://jaxodraw.sourceforge.net/license.html
 *  or the LICENSE file in the jaxodraw distribution.
 */
package net.sf.jaxodraw.object.fill;

import java.awt.Color;
import java.awt.geom.Point2D;

import net.sf.jaxodraw.object.JaxoExtendedObject;
import net.sf.jaxodraw.object.JaxoFillColorObject;
import net.sf.jaxodraw.object.JaxoObject;
import net.sf.jaxodraw.util.JaxoColor;
import net.sf.jaxodraw.util.JaxoGeometry;


/** A general object that can be filled.
 * @since 2.0
 */
public abstract class JaxoFillObject extends JaxoExtendedObject
    implements JaxoFillColorObject {
    /** The fill color of this fillObject. */
    private Color fillColor;
    private boolean filled = true;

    // Bean getter and setter methods

    /** {@inheritDoc} */
    public final Color getFillColor() {
        return fillColor;
    }

    /** {@inheritDoc} */
    public final void setFillColor(Color color) {
        Color old = fillColor;
        this.fillColor = color;
        firePropertyChange("fillColor", old, fillColor);
    }

    /** {@inheritDoc} */
    public final boolean isFilled() {
        return filled;
    }

    /** {@inheritDoc} */
    public final void setFilled(boolean value) {
        Boolean old = Boolean.valueOf(filled);
        filled = value;
        firePropertyChange("filled", old, Boolean.valueOf(filled));
    }

    /** {@inheritDoc} */
    public boolean isCopy(JaxoObject comp) {
        boolean isCopy = false;

        if (comp instanceof JaxoFillObject) {
            JaxoFillObject tmp = (JaxoFillObject) comp;
            if ((tmp.getFillColor().equals(getFillColor()))
                    && (tmp.isFilled() == isFilled()) && super.isCopy(tmp)) {
                isCopy = true;
            }
        }

        return isCopy;
    }

    /** Sets all parameters from the given object to the current one.
     * @param temp The object to copy from.
     */
    public void copyFrom(JaxoFillObject temp) {
        super.copyFrom(temp);
        setFillColor(temp.getFillColor());
        setFilled(temp.isFilled());
    }

    /** {@inheritDoc} */
    public void setState(JaxoObject o) {
        copyFrom((JaxoFillObject) o);
    }

    /** {@inheritDoc} */
    public void rescaleObject(int orx, int ory, float scale) {
        int newRelWidth = Math.round(this.getRelSize().width * scale);
        int newRelHeight = Math.round(this.getRelSize().height * scale);

        Point2D newP =
            JaxoGeometry.scaledPoint(orx, ory, scale, getX(), getY());

        setLocation((int) Math.round(newP.getX()),
            (int) Math.round(newP.getY()));

        this.setRelWAndH(newRelWidth, newRelHeight);
    }

    /** {@inheritDoc} */
    public void setPreferences() {
        super.setPreferences();
        setFilled(true);
        setFillColor(JaxoColor.getDefaultFillColor(getColor()));
    }
}
