/**
 *  Licensed under GPL. For more information, see
 *    http://jaxodraw.sourceforge.net/license.html
 *  or the LICENSE file in the jaxodraw distribution.
 */
package net.sf.jaxodraw.object.loop;

import java.awt.geom.Ellipse2D;
import java.awt.geom.GeneralPath;

import net.sf.jaxodraw.object.JaxoObject;
import net.sf.jaxodraw.object.JaxoObjectEditPanel;


/** A fermion loop.
 * @since 2.0
 */
public class JaxoFLoop extends JaxoLoopObject {
    private static final long serialVersionUID = 314159L;

    /** {@inheritDoc} */
    public final boolean isCopy(JaxoObject comp) {
        boolean isCopy = false;

        if (comp instanceof JaxoFLoop) {
            isCopy = super.isCopy(comp);
        }

        return isCopy;

    }

    /** {@inheritDoc} */
    public void prepareEditPanel(JaxoObjectEditPanel editPanel) {
        int r = (int) Math.round(getRadius());

        editPanel.addXYRPanel(getX(), getY(), r, 0, 0);
        //editPanel.addArrowPanel(isPaintArrow(), isFlip(), false, false, 1, 0);
        editPanel.addArrowPanel(isPaintArrow(), isFlip(), getArrowPosition(), 1, 0);
        editPanel.addArrowOptionsEditPanel(getArrow(), 2, 0);
        editPanel.addStrokePanel(getStrokeWidth(), 0, 1);
        editPanel.addDoubleLinePanel(isDoubleLine(), getDLSeparation(), 1, 1);
        editPanel.addColorPanel(getColor(), JaxoObjectEditPanel.TYPE_LINE_COLOR, 2, 1);

        editPanel.setTitleAndIcon("Fermion_loop_parameters", "floop.png");
    }

    /** {@inheritDoc} */
    protected GeneralPath getObjectPath() {
        GeneralPath gp = getGeneralPath();
        gp.reset();

        double length = getRadius();
        float dlsep = getDLSeparation() / 2.f;

        Ellipse2D loop = new Ellipse2D.Double();
        if (isDoubleLine()) {
            loop.setFrame(-length - dlsep + getX(), -length - dlsep + getY(),
                2 * (length + dlsep), 2 * (length + dlsep));
            gp.append(loop, false);
            loop.setFrame(-length + dlsep + getX(), -length + dlsep + getY(),
                2 * (length - dlsep), 2 * (length - dlsep));
            gp.append(loop, false);
        } else {
            loop.setFrame(-length + getX(), -length + getY(), 2 * length,
                2 * length);
            gp.append(loop, false);
        }

        return gp;
    }

    // Get the axodraw4j options set for this loop

    /** {@inheritDoc} */
    protected String getAxo4JOptions(float scale) {

        String optioncmd = ""; //all loops are anti-clockwise

        if (isPaintArrow()) {
            float arpos = getArrowPosition();
            optioncmd = this.getArrow().latexCommand(arpos, scale);

            if (isFlip()) {
                optioncmd = optioncmd + ",flip";
            }

            if (isDoubleLine()) {
                optioncmd = optioncmd + ",double,sep="
                    + D_FORMAT.format(this.getDLSeparation());
            }

            optioncmd = "[" + optioncmd + "]";

        } else if (isDoubleLine()) {
            optioncmd = "[double,sep="
                + D_FORMAT.format(this.getDLSeparation()) + "]";
        }

        return optioncmd;
    }
}
