/**
 *  Licensed under GPL. For more information, see
 *    http://jaxodraw.sourceforge.net/license.html
 *  or the LICENSE file in the jaxodraw distribution.
 */
package net.sf.jaxodraw.util.graphics;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Stroke;

import net.sf.jaxodraw.util.JaxoColor;


/** Graphic2Ds that also stores JaxoDraw-specific state and can
 * perform JaxoDraw-specific painting.
 * @since 2.0
 */
public class JaxoGraphics2D extends JaxoWrapperGraphics2D {
    /** Default visualAid color. */
    public static final Color DEFAULT_HELP_COLOR = JaxoColor.RED;

    /** Default visualAid Stroke. */
    public static final Stroke DEFAULT_HELP_STROKE = new BasicStroke(1);

    private boolean printing;

    /**
     * Constructor.
     * @param g The Graphics2D object.
     */
    public JaxoGraphics2D(Graphics2D g) {
        super(g);
    }

    /**
     * If printing is active, do not paint any UI-elements or aids.
     * @return True if printing is active.
     */
    public final boolean isPrinting() {
        return printing;
    }

    /**
     * Sets whether printing is currently active.
     * @param value True if printing is active.
     */
    public void setPrinting(boolean value) {
        printing = value;
    }
}
