/**
 *  Licensed under GPL. For more information, see
 *    http://jaxodraw.sourceforge.net/license.html
 *  or the LICENSE file in the jaxodraw distribution.
 */

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.IOException;
import java.io.OutputStream;

import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.SourceLocator;
import javax.xml.transform.Templates;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.URIResolver;

import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;

public class UserGuide2HTML {

    public static void main(String[] args) {
        UserGuide2HTML transform = new UserGuide2HTML();
        transform.transform();
    }

    private void transform() {
        boolean succeed = false;
        String sourceDirName = "src/main/resources/usrGuide/xdocs/";
        String xslFileName = sourceDirName + "style/style.xsl";
        String targetDirName = "build/resources/usrGuide/";
        File targetDir = new File(targetDirName);
        try {
            if (targetDir.exists()) {
                succeed = deleteDir(targetDir);
                System.out.println("Warning: Directory " + targetDir
                    + " will be recreated!");
                if (!succeed) {
                    System.out.println(targetDir + " could not be deleted!");
                }
            }
            succeed = targetDir.mkdirs();
            if (!succeed) {
                System.out.println(targetDir + " could not be created!");
            }
        } catch (SecurityException e) {
            e.printStackTrace();
        }
        String outFileNameBase = targetDirName;
        File sourceDir = new File(sourceDirName);
        String inFileNameBase = sourceDirName;
        File[] xmlFiles = sourceDir.listFiles();
        int nof = xmlFiles.length;
        for (int j = 0; j < nof; j++) {
            File xmlFile = xmlFiles[j];
            String filename = xmlFile.getName();
            String ext = "";
            String base = "";
            int i = filename.lastIndexOf('.');
            if ((i > 0) && (i < (filename.length() - 1))) {
                ext = filename.substring(i + 1).toLowerCase();
                base = filename.substring(0, i);
            }
            String outFileName = "";
            String inFileName = "";
            if (!filename.equals("navigation.xml")
                    && !filename.equals("pdf-navigation.xml")) {
                if (ext.equals("xml")) {
                    outFileName = outFileNameBase.concat(base) + ".html";
                    inFileName = inFileNameBase.concat(filename);
                    xsl(inFileName, outFileName, xslFileName);
                } else {
                    inFileName = inFileNameBase.concat(filename);
                    outFileName = outFileNameBase.concat(filename);
                    try {
                        copyDirectory(new File(inFileName),
                            new File(outFileName));
                    } catch (IOException e) {
                    }
                }
            }
        }
    }

    private void xsl(String inFilename, String outFilename,
        String xslFilename) {
        try {
            File xslFile = new File(xslFilename);
            String baseDir = xslFile.getParent();
            TransformerFactory factory = TransformerFactory.newInstance();
            Templates template =
                factory.newTemplates(new StreamSource(
                        new FileInputStream(xslFilename)));
            Transformer xformer = template.newTransformer();
            Source source = new StreamSource(new FileInputStream(inFilename));
            Result result =
                new StreamResult(new FileOutputStream(outFilename));
            MyResolver resolver = new MyResolver(baseDir);
            xformer.setURIResolver(resolver);
            xformer.setParameter("JDtitle", "JaxoDraw");
            xformer.setParameter("JDversion", "1.3-2");
            xformer.setOutputProperty("doctype-public",
                "-//W3C//DTD XHTML 1.0 Transitional//EN");
            xformer.setOutputProperty("doctype-system",
                "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd");
            xformer.transform(source, result);
        } catch (FileNotFoundException e) {
            System.out.println(e);
            e.printStackTrace();
        } catch (TransformerConfigurationException e) {
            System.out.println(e);
            e.printStackTrace();
        } catch (TransformerException e) {
            SourceLocator locator = e.getLocator();
            int col = locator.getColumnNumber();
            int line = locator.getLineNumber();
            String publicId = locator.getPublicId();
            String systemId = locator.getSystemId();
            System.out.println(e);
            e.printStackTrace();
            System.out.println("column: " + col);
            System.out.println("line: " + line);
            System.out.println("publicId: " + publicId);
            System.out.println("systemId: " + systemId);
        }
    }

    private void copyDirectory(File srcDir, File dstDir)
        throws IOException {
        if (srcDir.isDirectory()) {
            if (!dstDir.exists()) {
                dstDir.mkdir();
            }

            String[] children = srcDir.list();
            for (int i = 0; i < children.length; i++) {
                copyDirectory(new File(srcDir, children[i]),
                    new File(dstDir, children[i]));
            }
        } else {
            copyFile(srcDir, dstDir);
        }
    }

    private void copyFile(File src, File dst) throws IOException {
        InputStream in = new FileInputStream(src);
        OutputStream out = new FileOutputStream(dst);
        byte[] buf = new byte[1024];
        int len;
        while ((len = in.read(buf)) > 0) {
            out.write(buf, 0, len);
        }
        in.close();
        out.close();
    }

    private boolean deleteDir(File dir) {
        if (dir.isDirectory()) {
            String[] children = dir.list();
            for (int i = 0; i < children.length; i++) {
                boolean success = deleteDir(new File(dir, children[i]));
                if (!success) {
                    return false;
                }
            }
        }
        return dir.delete();
    }

    private class MyResolver implements URIResolver {
        String base_path;

        public MyResolver(String path) {
            this.base_path = path;
        }

        public Source resolve(String href, String base) {
            StringBuffer path = new StringBuffer(this.base_path);
            path.append(File.separator);
            path.append(href);
            File file = new File(path.toString());
            if (file.exists()) {
                return new StreamSource(file);
            }
            return null;
        }
    }
}
