<?xml version="1.0"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <!-- Output method -->
    <xsl:output method="html" encoding="iso-8859-1" indent="no"/>

    <!-- Defined parameters (overrideable) -->
    <xsl:param name="relative-path" select="'.'"/>
    <xsl:param name="JDtitle"/>
    <xsl:param name="JDversion"/>

    <!-- Defined variables (non-overrideable) -->
    <xsl:variable name="header-bg" select="'#ffffff'"/>
    <xsl:variable name="body-bg" select="'#ffffff'"/>
    <xsl:variable name="body-fg" select="'#000000'"/>
    <xsl:variable name="body-link" select="'#525D76'"/>
    <xsl:variable name="banner-bg" select="'#525D76'"/>
    <xsl:variable name="banner-fg" select="'#ffffff'"/>
    <xsl:variable name="sub-banner-bg" select="'#828DA6'"/>
    <xsl:variable name="sub-banner-fg" select="'#ffffff'"/>
    <xsl:variable name="table-th-bg" select="'#039acc'"/>
    <xsl:variable name="table-td-bg" select="'#a0ddf0'"/>
    <xsl:variable name="source-color" select="'#ffff99'"/>
    <xsl:variable name="toplinkitem-color" select="'#3366ff'"/>

    <!-- Process an entire document into an HTML page -->
    <xsl:template match="document">
        <xsl:comment>Do not edit this autogenerated HTML file; edit src/xdocs files instead. </xsl:comment>
        <xsl:variable name="project" select="document('../navigation.xml')/project"/>
        <html>
            <head>
                <style type="text/css"> @import url("./style/style.css"); </style>
                <xsl:apply-templates select="meta"/>
                <title>
                    <xsl:value-of select="$project/title"/> - <xsl:value-of select="properties/title"/>
                </title>
                <xsl:for-each select="properties/author">
                    <xsl:variable name="name">
                        <xsl:value-of select="."/>
                    </xsl:variable>
                    <xsl:variable name="email">
                        <xsl:value-of select="@email"/>
                    </xsl:variable>
                    <meta name="author" content="{$name}"/>
                    <meta name="email" content="{$email}"/>
                </xsl:for-each>
            </head>
            <body bgcolor="{$body-bg}" text="{$body-fg}" link="{$body-link}" alink="{$body-link}" vlink="{$body-link}">
                <xsl:comment>HEADER</xsl:comment>
                <h1><xsl:value-of select="$JDtitle"/>-<xsl:value-of select="$JDversion"/> -- User Guide</h1>
                <xsl:comment>TOP LINK MENU NAVIGATION</xsl:comment>
                <xsl:apply-templates select="$project/body/links"/>
                <xsl:apply-templates select="body/navbar"/>
                <xsl:apply-templates select="body/section"/>
                <xsl:apply-templates select="body/navbar"/>
            </body>
        </html>
    </xsl:template>



    <!-- Process a menu for the navigation bar -->
    <xsl:template match="menu">
        <div class="frame item">
            <div class="name">
                <xsl:value-of select="@name"/>
            </div>
            <div class="content">
                <xsl:apply-templates select="item"/>
            </div>
        </div>
    </xsl:template>

    <!-- Process a menuSeparator for the navigation bar -->
    <xsl:template match="menuSeparator">
        <p></p>
    </xsl:template>

    <!-- Process a menu item for the navigation bar -->
    <xsl:template match="item">
        <xsl:choose>
            <xsl:when test="@name = 'hr'">
                <hr noshade="noshade" size="1"/>
            </xsl:when>
            <xsl:when test="@href">
                <xsl:variable name="href">
                    <xsl:choose>
                        <xsl:when test="starts-with(@href, 'http://')">
                            <xsl:value-of select="@href"/>
                        </xsl:when>
                        <xsl:when test="starts-with(@href, 'https://')">
                            <xsl:value-of select="@href"/>
                        </xsl:when>
                        <xsl:when test="starts-with(@href, '#')">
                            <xsl:value-of select="@href"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="$relative-path"/>
                            <xsl:value-of select="@href"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>
                <a href="{$href}">
                    <xsl:value-of select="@name"/>
                </a>
            </xsl:when>
            <xsl:otherwise>
                <div>
                    <xsl:value-of select="@name"/>
                </div>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates select="subitem"/>
    </xsl:template>

    <!-- Process a menu item for the navigation bar -->
    <xsl:template match="subitem">
        <xsl:choose>
            <xsl:when test="@name = 'hr'">
                <hr noshade="noshade" size="1"/>
            </xsl:when>
            <xsl:when test="@href">
                <xsl:variable name="href">
                    <xsl:choose>
                        <xsl:when test="starts-with(@href, 'http://')">
                            <xsl:value-of select="@href"/>
                        </xsl:when>
                        <xsl:when test="starts-with(@href, 'https://')">
                            <xsl:value-of select="@href"/>
                        </xsl:when>
                        <xsl:when test="starts-with(@href, '/site')">
                            <xsl:text>http://jakarta.apache.org</xsl:text>
                            <xsl:value-of select="@href"/>
                        </xsl:when>
                        <xsl:when test="starts-with(@href, '#')">
                            <xsl:value-of select="@href"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="$relative-path"/>
                            <xsl:value-of select="@href"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>
                <a href="{$href}">
                &#160;&#160;&#160;&#160;-
                    <xsl:value-of select="@name"/>
                </a>
            </xsl:when>
            <xsl:otherwise>
                <div>
                &#160;&#160;&#160;&#160;-
                <xsl:value-of select="@name"/>
                </div>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- Process top link menu navigation bar -->
    <xsl:template match="links">
        <div align="center" style="font-size: 100%">
            <table>
                <tr>
                    <xsl:for-each select="../menu/item">
                        <td><xsl:call-template name="linkitem"/></td>
                    </xsl:for-each>
                </tr>
            </table>
        </div>
    </xsl:template>

    <!-- Process a topmenu item for the top navigation bar -->
    <xsl:template name="linkitem">
        <xsl:variable name="href">
            <xsl:choose>
                <xsl:when test="starts-with(@href, 'http://')">
                    <xsl:value-of select="@href"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$relative-path"/>
                    <xsl:value-of select="@href"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <a href="{$href}">
            <xsl:attribute name="title">
                <xsl:value-of select="@name"/>
            </xsl:attribute>
            <xsl:value-of select="@name"/>
        </a> 
    </xsl:template>

    <!-- Process a documentation section -->
    <xsl:template match="section">
        <xsl:variable name="name">
            <xsl:value-of select="@name"/>
        </xsl:variable>
        <xsl:variable name="linkname">
            <xsl:value-of select="translate(@name,' ','_')"/>
        </xsl:variable>
        <table border="0" cellspacing="0" cellpadding="2" width="100%">
            <!-- Section heading -->
            <tr>
                <td bgcolor="{$banner-bg}">
                    <font color="{$banner-fg}" face="arial,helvetica.sanserif">
                        <a name="{$linkname}">
                            <strong>
                                <xsl:value-of select="@name"/>
                            </strong>
                        </a>
                    </font>
                </td>
            </tr>
            <!-- Section body -->
            <tr>
                <td>
                    <blockquote>
                        <xsl:apply-templates/>
                    </blockquote>
                </td>
            </tr>
        </table>
    </xsl:template>

    <!-- Process a documentation subsection -->
    <xsl:template match="subsection">
        <xsl:variable name="name">
            <xsl:value-of select="@name"/>
        </xsl:variable>
        <xsl:variable name="linkname">
            <xsl:value-of select="translate(@name,' ','_')"/>
        </xsl:variable>
        <table border="0" cellspacing="0" cellpadding="2" width="100%">
            <!-- Subsection heading -->
            <tr>
                <td bgcolor="{$sub-banner-bg}">
                    <font color="{$sub-banner-fg}" face="arial,helvetica.sanserif">
                        <a name="{$linkname}">
                            <strong>
                                <xsl:value-of select="@name"/>
                            </strong>
                        </a>
                    </font>
                </td>
            </tr>
            <!-- Subsection body -->
            <tr>
                <td>
                    <blockquote>
                        <xsl:apply-templates/>
                    </blockquote>
                </td>
            </tr>
        </table>
    </xsl:template>


    <!-- process a listing element -->
    <xsl:template match="listing">
        <xsl:variable name="name">
            <xsl:value-of select="@name"/>
        </xsl:variable>
        <div class="frame listing">
            <div class="name">
                <a name="{$name}">
                    <xsl:value-of select="@name"/>
                </a>
            </div>
            <div class="listingcontent">
                <xsl:apply-templates/>
            </div>
        </div>
    </xsl:template>

    <xsl:template match="navbar">
        <hr/>
        <table border="0" cellspacing="0" cellpadding="2" width="100%">
          <tr>
            <td align="left">
            <xsl:choose>
                <xsl:when test="@previous">
                    <xsl:variable name="prev">
                        <xsl:value-of select="@previous"/>
                    </xsl:variable>
                    <a href="{$prev}">Prev</a>
                </xsl:when>
                <xsl:otherwise>Prev</xsl:otherwise>
            </xsl:choose>
            </td>
            <td align="center"><a href="index.html">Home</a></td>
            <td align="right">
            <xsl:choose>
                <xsl:when test="@next">
                    <xsl:variable name="next">
                        <xsl:value-of select="@next"/>
                    </xsl:variable>
                    <a href="{$next}">Next</a>
                </xsl:when>
                <xsl:otherwise>Next</xsl:otherwise>
            </xsl:choose>
            </td>
          </tr>
        </table>
    </xsl:template>

    <!-- Process everything else by just passing it through -->
    <xsl:template match="*|@*">
        <xsl:copy>
            <xsl:apply-templates select="@*|*|text()"/>
        </xsl:copy>
    </xsl:template>


    <!-- Process a source code example -->
    <xsl:template match="source">
        <pre><xsl:apply-templates/></pre>
    </xsl:template>

</xsl:stylesheet>
