/**
 *  Licensed under GPL. For more information, see
 *    http://jaxodraw.sourceforge.net/license.html
 *  or the LICENSE file in the jaxodraw distribution.
 */
package net.sf.jaxodraw.gui.panel;

import java.awt.Point;

import java.beans.PropertyChangeEvent;

import java.io.File;
import junit.framework.TestCase;

import net.sf.jaxodraw.gui.JaxoTab;
import net.sf.jaxodraw.io.JaxoIO;
import net.sf.jaxodraw.util.JaxoDictionary;

/** Tests for JaxoFlags. */
public class JaxoFlagsTest extends TestCase {
    private static final JaxoDictionary LANGUAGE = new JaxoDictionary(JaxoFlags.class);
    /** Constructor: just calls super().
     * @param testName The name of this test.
     */
    public JaxoFlagsTest(String testName) {
        super(testName);
    }

    /** Tests JaxoFlags with a null tab. */
    public void testDefaults() {
        JaxoFlags flagPanel = new JaxoFlags();
        String expected = LANGUAGE.value("mouseCoordinates_none");
        String actual = flagPanel.getCurrentCoordinateText();
        assertEquals("Coordinate text not correct!", expected, actual);

        expected = LANGUAGE.value("mode_none");
        actual = flagPanel.getCurrentModeText();
        assertEquals("Mode text not correct!", expected, actual);

        int max = 46;
        String filename = JaxoIO.currentDirectoryString();
        if (filename.length() > max) {
            expected = LANGUAGE.message(
                    "directory%0ending",
                    filename.substring(filename.length() - max));
        } else {
            expected = LANGUAGE.message("directory%0", filename);
        }
        actual = flagPanel.getCurrentFileText();
        assertEquals("Coordinate text not correct!", expected, actual);
    }

    /** Test of propertyChange method in JaxoDraw.JaxoFlags. */
    public void testPropertyChange() {
        Object source = (Object) this;
        String name = "Jaxo.mouseLocation";
        Object oldOb = null;
        Point point = new Point(20, 30);
        Object newOb = (Object) point;
        PropertyChangeEvent event =
            new PropertyChangeEvent(source, name, oldOb, newOb);

        JaxoFlags flagPanel = new JaxoFlags();
        flagPanel.propertyChange(event);
        String expected = LANGUAGE.message(
            "mouseCoordinates%0%1", new Integer(point.x),
                new Integer(point.y));
        String actual = flagPanel.getCurrentCoordinateText();
        assertEquals("Coordinate text not correct!", expected, actual);

        JaxoTab tab = new JaxoTab();
        File saveFile =
                new File(JaxoIO.currentDirectoryString(), "saveFileName");
        String saveFileName = saveFile.getAbsolutePath();
        tab.setSaveFileName(saveFileName);
        newOb = (Object) tab;
        name = "Jaxo.selectedTab";
        event = new PropertyChangeEvent(source, name, oldOb, newOb);
        flagPanel.propertyChange(event);
        String filename = JaxoIO.directoryString(saveFileName);
        expected = LANGUAGE.message("directory%0", filename);

        int max = 46;
        if (filename.length() > max) {
            expected = LANGUAGE.message("directory%0ending",
                    filename.substring(filename.length() - max));
        }

        actual = flagPanel.getCurrentFileText();
        assertEquals("File text not correct!", expected, actual);
    }
}
