/**
 *  Licensed under GPL. For more information, see
 *    http://jaxodraw.sourceforge.net/license.html
 *  or the LICENSE file in the jaxodraw distribution.
 */
package net.sf.jaxodraw.io.exports;

import java.awt.Dimension;

import java.io.File;

/**
 * Test for JaxoExportPS.
 */
public class JaxoExportPSTest extends AbstractJaxoExportTest {
    private final JaxoExportPS exportPS = new JaxoExportPS(JaxoExportPS.PS_PS);
    private final JaxoExportPS exportEPS = new JaxoExportPS(JaxoExportPS.PS_EPS);

    /** Constructor.
     * @param testName The name of this test.
     */
    public JaxoExportPSTest(String testName) {
        super(testName);
    }

    /**
     * Test of getFileExtension method, of class net.sf.jaxodraw.io.export.JaxoExportPS.
     */
    public void testGetFileExtension() {
        String expResult = "ps";
        String result = exportPS.getFileExtension();
        assertEquals(expResult, result);

        expResult = "eps";
        result = exportEPS.getFileExtension();
        assertEquals(expResult, result);
    }

    /**
     * Test of exportTo method, of class net.sf.jaxodraw.io.export.JaxoExportPS.
     * @throws Exception Exception.
     */
    public void testExportTo() throws Exception {
        Dimension canvasD = new Dimension(800, 600);

        File ps = getOutputFile(getBase(), "psExportTest.ps");

        exportPS.setGraph(getTestGraph());
        exportPS.setCanvasSize(canvasD);
        exportPS.exportTo(ps.getAbsolutePath());

        assertTrue("No ps file created!", ps.exists());
        assertTrue("Empty ps file created!", ps.length() > 0);


        File eps = getOutputFile(getBase(), "epsExportTest.eps");

        exportEPS.setGraph(getTestGraph());
        exportEPS.setCanvasSize(canvasD);
        exportEPS.exportTo(eps.getAbsolutePath());

        assertTrue("No eps file created!", eps.exists());
        assertTrue("Empty eps file created!", eps.length() > 0);
    }

    /** {@inheritDoc} */
    public JaxoExport getInstance() {
        return new JaxoExportPS(JaxoExportPS.PS_EPS);
    }
}
