/**
 *  Licensed under GPL. For more information, see
 *    http://jaxodraw.sourceforge.net/license.html
 *  or the LICENSE file in the jaxodraw distribution.
 */
package net.sf.jaxodraw.object;

import java.awt.Color;

import java.util.ArrayList;
import java.util.Collection;

import net.sf.jaxodraw.AbstractJaxoBaseTest;
import net.sf.jaxodraw.object.line.JaxoFLine;
import net.sf.jaxodraw.object.loop.JaxoFLoop;

/**
 *
 */
public class JaxoObjectListTest extends AbstractJaxoBaseTest {

    /**
     * Constructor.
     *
     * @param testName The name of this test.
     */
    public JaxoObjectListTest(String testName) {
        super(testName);
    }

    /**
     * Test of constructors, of class JaxoObjectList.
     */
    public void testConstructor() {
        Collection list = new ArrayList(2);
        list.add(new JaxoFLine());
        list.add(new JaxoFLoop());
        JaxoObjectList instance = new JaxoObjectList(list);
        assertEquals(2, instance.size());

        list = new ArrayList(1);
        list.add("");

        try {
            instance = new JaxoObjectList(list);
            fail("added non-JaxoObject");
        } catch (ClassCastException e) {
            assertNotNull(e);
        }
    }

    /**
     * Test of add method, of class JaxoObjectList.
     */
    public void testAdd() {
        JaxoObjectList instance = new JaxoObjectList();
        try {
            instance.add("");
            fail("added non-JaxoObject");
        } catch (ClassCastException e) {
            assertNotNull(e);
            assertTrue(instance.add(new JaxoFLine()));
        }

        assertEquals(1, instance.size());

        try {
            instance.add(0, "");
            fail("added non-JaxoObject");
        } catch (ClassCastException e) {
            assertNotNull(e);
            instance.add(0, new JaxoFLine());
            assertEquals(2, instance.size());
            instance.add(1, new JaxoFLine());
            assertEquals(3, instance.size());
        }
    }

    /**
     * Test of addAll method, of class JaxoObjectList.
     */
    public void testAddAll() {
        Collection list = new ArrayList(2);
        list.add(new JaxoFLine());
        list.add(new JaxoFLoop());
        JaxoObjectList instance = new JaxoObjectList();
        instance.addAll(list);
        assertEquals(2, instance.size());
        list.add(new JaxoFLine());
        instance.addAll(1, list);
        assertEquals(5, instance.size());

        list = new ArrayList(1);
        list.add("");

        try {
            instance.addAll(list);
            fail("added non-JaxoObject");
        } catch (ClassCastException e) {
            assertNotNull(e);
        }

        try {
            instance.addAll(0, list);
            fail("added non-JaxoObject");
        } catch (ClassCastException e) {
            assertNotNull(e);
        }
    }

    /**
     * Test of set method, of class JaxoObjectList.
     */
    public void testSet() {
        JaxoObjectList instance = new JaxoObjectList();
        instance.add(new JaxoFLine());
        instance.set(0, new JaxoFLoop());
        assertTrue(instance.get(0) instanceof JaxoFLoop);

        try {
            instance.set(0, "");
            fail("set non-JaxoObject");
        } catch (ClassCastException e) {
            assertNotNull(e);
        }
    }

    /**
     * Test of isCopy method, of class JaxoObjectList.
     */
    public void testIsCopy() {
        JaxoObjectList instance = new JaxoObjectList();
        assertFalse(instance.isCopy(null));
        assertTrue(instance.isCopy(instance));
    }

    /**
     * Test of moveAllObjects method, of class JaxoObjectList.
     */
    public void testMoveAllObjects() {
        JaxoFLine line = new JaxoFLine();
        JaxoFLoop loop = new JaxoFLoop();
        line.setLocation(100, 100, 200, 200);
        loop.setLocation(300, 400, 500, 600);
        JaxoObjectList instance = new JaxoObjectList();
        instance.add(line);
        instance.add(loop);

        instance.moveAllObjects(0, 0);
        assertEquals(100, line.getX());
        assertEquals(300, loop.getX());
        assertEquals(100, line.getY());
        assertEquals(400, loop.getY());

        instance.moveAllObjects(100, -100);
        assertEquals(200, line.getX());
        assertEquals(400, loop.getX());
        assertEquals(0, line.getY());
        assertEquals(300, loop.getY());
    }

    /**
     * Test of setColor method, of class JaxoObjectList.
     */
    public void testSetColor() {
        Color color = Color.BLUE;
        JaxoObjectList instance = new JaxoObjectList();
        JaxoFLine line = new JaxoFLine();
        line.setColor(Color.GREEN);
        instance.add(line);
        instance.setColor(color);
        assertEquals(line.getColor(), Color.BLUE);
    }


}
